@@ -8,10 +8,11 @@ sys.path.append('.')
 from wsgi_intercept import httplib2_intercept
 import wsgi_intercept
 import httplib2
+import simplejson
 
 from tiddlyweb.model.bag import Bag
 
-from fixtures import muchdata, reset_textstore, teststore
+from fixtures import muchdata, reset_textstore, _teststore
 
 def setup_module(module):
     from tiddlyweb.web import serve
@@ -23,10 +24,18 @@ def setup_module(module):
     httplib2_intercept.install()
     wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
 
-    module.store = teststore()
     reset_textstore()
+    module.store = _teststore()
     muchdata(module.store)
 
+def test_get_sorted_tiddlers():
+    http = httplib2.Http()
+    response, content = http.request('http://our_test_domain:8001/bags/bag0/tiddlers.json?sort=title',
+            method='GET')
+    assert response['status'] == '200'
+    tiddlers = simplejson.loads(content)
+    assert tiddlers[0]['title'] == 'tiddler0'
+
 def test_post_wiki_to_bag():
     bag = Bag('wikibag')
     store.put(bag)
